@@ -70,7 +70,7 @@ import static org.jruby.runtime.Visibility.PRIVATE;
 public class RubyStringScanner extends RubyObject {
     private static final long serialVersionUID = -3722138049229128675L;
 
-    private static final String STRSCAN_VERSION = "3.1.4";
+    private static final String STRSCAN_VERSION = "3.1.5";
 
     private RubyString str;
     private int curr = 0;
@@ -589,7 +589,7 @@ public class RubyStringScanner extends RubyObject {
             len++;
         }
 
-        if (!Character.isDigit(bytes.get(ptr + len))) {
+        if (len >= remaining_len || !Character.isDigit(bytes.get(ptr + len))) {
             return context.nil;
         }
 
@@ -651,7 +651,7 @@ public class RubyStringScanner extends RubyObject {
         setMatched();
         adjustRegisters();
 
-        return ConvertBytes.byteListToInum(runtime, bytes, ptr, len, base, true);
+        return ConvertBytes.byteListToInum(runtime, bytes, ptr, ptr + len, base, true);
     }
 
     private void strscanMustAsciiCompat(Ruby runtime) {
